from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_HC11 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'68HC11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68HC11'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MCU Microcontroller HC11', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\n68HC11\n\nMCU Microcontroller HC11', 'pins':[
            Pin(num='1',name='PAI/PA7',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OC2/PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MODA',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OC3/PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='AD0/PC0',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='PC1',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='PC2',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='PC3',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='PC4',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='PC5',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='PC6',func=pin_types.TRISTATE,unit=1),
            Pin(num='38',name='AD7/PC7',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='OC4/PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PD0/RX',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='PD1/TX',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PD2/MISO',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PD3/MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PD4/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PD5/SS-',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OC5/PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='IC1/PA2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IC2/PA1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IC3/PA0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A15/PB7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68HC11F1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68HC11F1'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MCU Microcontroller HC11', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC68HC11FTS.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\n68HC11F1\n\nMCU Microcontroller HC11', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D7/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB/STBY',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CSPROG/PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CSGEN/PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='CSIO1/PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CSIO2/PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PG3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/RX',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD1/TX',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MODA/LR',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PD2/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD3/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD4/SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD5/SS-',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA1/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='OC2/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='OC3/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='OC4/PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='OC5/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='IC1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IC2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IC3/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='PB1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='A8/PB0',func=pin_types.TRISTATE,unit=1),
            Pin(num='51',name='A7/PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='A0/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='4XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D0/PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68HC11_PLCC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68HC11_PLCC'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MCU Microcontroller HC11', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\n68HC11_PLCC\n\nMCU Microcontroller HC11', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AD1/PC1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='AD2/PC2',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='AD3/PC3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='AD4/PC4',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='AD5/PC5',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='AD6/PC6',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='AD7/PC7',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PD0/RX',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1/TX',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PA1/PA7',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='OC2/PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='OC3/PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MODA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OC4/PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OC5/PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='IC1/PA2',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='IC2/PA1',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='IC3/PA0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AD0/PC0',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68HC711_PLCC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68HC711_PLCC'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MCU Microcontroller HC11', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\n68HC711_PLCC\n\nMCU Microcontroller HC11', 'pins':[
            Pin(num='1',name='EVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC7',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='XIRQ/VPP',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PD7-R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='PD6-AS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IRQ/CE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PD0/RX',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PD1/TX',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PD3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD4',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PD5',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA1/PA7',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OC2/PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OC3/PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='OC4/PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OC5/PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='IC1/PA2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='IC2/PA1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='PC0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IC3/PA0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PB7/OE',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PC1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='MODA',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PC3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PC4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC5',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC6',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68HC11A8CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC11A8CC'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HC11 MCU Microcotroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\nMC68HC11A8CC\n\nHC11 MCU Microcotroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AD1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AD2/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AD3/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AD4/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AD5/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AD6/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AD7/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{XIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RXD/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TXD/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='MIS/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='MOS/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCK/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SS/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='PA2',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='PA1',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PA0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='A14/PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='A13/PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='A12/PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A11/PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='A10/PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='A9/PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AD0/PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68HC11F1CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC11F1CC'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-68'], 'footprint':'Package_LCC:PLCC-68', 'keywords':'HC11 MCU Microcontroller', 'description':'', 'datasheet':'http://cache.freescale.com/files/microcontrollers/doc/data_sheet/MC68HC11F1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\nMC68HC11F1CC\n\nHC11 MCU Microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='D1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D2/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='D3/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D4/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='D5/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='D6/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D7/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{XIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CSPROG/PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CSGEN/PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='CSIO1/PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CSIO2/PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RXD/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TXD/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='MIS/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='MOS/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='SCK/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SS/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='A14/PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='A13/PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='A12/PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='A11/PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='A10/PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='A9/PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='A7/PF7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='A6/PF6',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='A5/PF5',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='A4/PF4',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='A3/PF3',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='A2/PF2',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='A1/PF1',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='A0/PF0',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='EXTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='4XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D0/PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68HC11A8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68HC11A8'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'MCU Microcontroller HC11', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\n68HC11A8\n\nMCU Microcontroller HC11', 'pins':[
            Pin(num='1',name='PAI/PA7',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OC2/PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MODA',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OC3/PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='AD0/PC0',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='PC1',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='PC2',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='PC3',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='PC4',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='PC5',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='PC6',func=pin_types.TRISTATE,unit=1),
            Pin(num='38',name='AD7/PC7',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='OC4/PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PD0/RX',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='PD1/TX',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PD2/MISO',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PD3/MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PD4/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PD5/SS-',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OC5/PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='IC1/PA2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IC2/PA1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IC3/PA0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A15/PB7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68HC11A0CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC11A0CC'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'HC11 MCU Microcotroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\nMC68HC11A0CC\n\nHC11 MCU Microcotroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AD1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AD2/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AD3/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AD4/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AD5/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AD6/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AD7/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{XIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RXD/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TXD/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='MIS/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='MOS/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCK/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SS/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='PA2',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='PA1',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PA0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='A14/PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='A13/PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='A12/PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A11/PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='A10/PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='A9/PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AD0/PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68HC11A1CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC11A1CC'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'HC11 MCU Microcotroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\nMC68HC11A1CC\n\nHC11 MCU Microcotroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AD1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AD2/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AD3/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AD4/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AD5/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AD6/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AD7/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{XIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RXD/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TXD/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='MIS/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='MOS/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCK/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SS/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='PA2',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='PA1',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PA0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='A14/PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='A13/PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='A12/PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A11/PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='A10/PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='A9/PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AD0/PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68HC11A7CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC11A7CC'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HC11 MCU Microcotroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC11.kicad_sym\nMC68HC11A7CC\n\nHC11 MCU Microcotroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AD1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AD2/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AD3/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AD4/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AD5/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AD6/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AD7/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{XIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MODB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RXD/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TXD/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='MIS/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='MOS/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCK/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SS/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='PA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='PA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='PA2',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='PA1',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PA0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15/PB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='A14/PB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='A13/PB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='A12/PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A11/PB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='A10/PB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='A9/PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='A8/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='PE0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PE4',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PE1',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PE5',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PE2',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='PE6',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PE3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='PE7',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AD0/PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Mechanical = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'DIN_Rail_Adapter', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN_Rail_Adapter'}), 'ref_prefix':'DRA', 'fplist':[''], 'footprint':'', 'keywords':'Mounting holes, DIN rail adapter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nDIN_Rail_Adapter\n\nMounting holes, DIN rail adapter' }),
        Part(**{ 'name':'Fiducial', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fiducial'}), 'ref_prefix':'FID', 'fplist':[''], 'footprint':'', 'keywords':'fiducial marker', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nFiducial\n\nfiducial marker' }),
        Part(**{ 'name':'Heatsink', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Heatsink'}), 'ref_prefix':'HS', 'fplist':[''], 'footprint':'', 'keywords':'thermal heat temperature', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nHeatsink\n\nthermal heat temperature' }),
        Part(**{ 'name':'Heatsink_Pad', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Heatsink_Pad'}), 'ref_prefix':'HS', 'fplist':[''], 'footprint':'', 'keywords':'thermal heat temperature', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nHeatsink_Pad\n\nthermal heat temperature', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Heatsink_Pad_2Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Heatsink_Pad_2Pin'}), 'ref_prefix':'HS', 'fplist':[''], 'footprint':'', 'keywords':'thermal heat temperature', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nHeatsink_Pad_2Pin\n\nthermal heat temperature', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Heatsink_Pad_3Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Heatsink_Pad_3Pin'}), 'ref_prefix':'HS', 'fplist':[''], 'footprint':'', 'keywords':'thermal heat temperature', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nHeatsink_Pad_3Pin\n\nthermal heat temperature', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Housing', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Housing'}), 'ref_prefix':'N', 'fplist':[''], 'footprint':'', 'keywords':'housing enclosure', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nHousing\n\nhousing enclosure' }),
        Part(**{ 'name':'Housing_Pad', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Housing_Pad'}), 'ref_prefix':'N', 'fplist':[''], 'footprint':'', 'keywords':'housing enclosure shield', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nHousing_Pad\n\nhousing enclosure shield', 'pins':[
            Pin(num='1',name='PAD',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MountingHole', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MountingHole'}), 'ref_prefix':'H', 'fplist':[''], 'footprint':'', 'keywords':'mounting hole', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nMountingHole\n\nmounting hole' }),
        Part(**{ 'name':'MountingHole_Pad', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MountingHole_Pad'}), 'ref_prefix':'H', 'fplist':[''], 'footprint':'', 'keywords':'mounting hole', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nMountingHole_Pad\n\nmounting hole', 'pins':[
            Pin(num='1',name='1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MountingHole_Pad_MP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MountingHole_Pad_MP'}), 'ref_prefix':'H', 'fplist':[''], 'footprint':'', 'keywords':'mounting hole', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Mechanical.kicad_sym\nMountingHole_Pad_MP\n\nmounting hole', 'pins':[
            Pin(num='MP',name='MP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])